{#
  This is where theme_css_variables or html_theme_options["css_variables"] gets
  converted to actual CSS variables.
#}
<style>
  :root {
    --color-code-background: {{ furo_pygments.background }};
    --color-code-foreground: {{ furo_pygments.foreground }};
  {% if theme_css_variables %}
  {% for name, value in theme_css_variables.items() %}
    --{{ name }}: {{ value }};
  {% endfor %}
  {% endif %}
  }
</style>
